@@ -13,7 +13,7 @@ sys.path.append("..")
 sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
 
 # can be either pip or local relative dir
-from py2cfg import CFGBuilder
+from py2cfg.builder import CFGBuilder
 
 
 if __name__ == "__main__":
@@ -24,6 +24,13 @@ if __name__ == "__main__":
         "input_file",
         help="Path to a file containing a Python program for which the CFG must be generated",
     )
+    parser.add_argument(
+        "--short",
+        nargs=1,
+        type=bool,
+        default=True,
+        help="Shorten all strings above 20 characters",
+    )
     parser.add_argument(
         "--format",
         nargs=1,
@@ -32,11 +39,7 @@ if __name__ == "__main__":
         help="File format of the generated cfg",
     )
     parser.add_argument(
-        "--calls",
-        nargs=1,
-        type=bool,
-        default=True,
-        help="Toggle call graph",
+        "--calls", nargs=1, type=bool, default=True, help="Toggle call graph",
     )
     parser.add_argument(
         "--show", nargs=1, type=bool, default=False, help="Open CFG after generation"
@@ -44,7 +47,7 @@ if __name__ == "__main__":
 
     args = parser.parse_args()
     cfg_name = args.input_file.split("/")[-1]
-    cfg = CFGBuilder().build_from_file(cfg_name, args.input_file)
+    cfg = CFGBuilder(args.short).build_from_file(cfg_name, args.input_file)
 
     # Some options for wrapping:
     # cfg.build_visual(cfg_name[:-3] + '_cfg', format='pdf', calls=True)
@@ -52,10 +55,7 @@ if __name__ == "__main__":
     # cfg.build_visual(cfg_name[:-3] + "_cfg", format="png", calls=True, show=False)
     # cfg.build_visual('controlflowgraph', format='png', calls=True, show=False)
     cfg.build_visual(
-        cfg_name[:-3] + "_cfg",
-        format=args.format,
-        calls=args.calls,
-        show=args.show,
+        cfg_name[:-3] + "_cfg", format=args.format, calls=args.calls, show=args.show,
     )
     # removes the CFG file, which maybe we could just turn off?
     os.remove(cfg_name[:-3] + "_cfg")
