@@ -8,7 +8,7 @@ Control flow graph builder.
 from typing import List, Optional
 import ast  # type: ignore
 from _ast import (
-    Assign,
+    Import, Break, AnnAssign, For, ImportFrom, Assign,
     AugAssign,
     Call,
     ClassDef,
@@ -22,7 +22,7 @@ from _ast import (
     While,
     Yield,
 )  # type: ignore
-from .model import Block, Link, CFG
+from py2cfg.model import Block, Link, CFG
 
 
 def invert(node: Compare) -> Compare:
@@ -61,7 +61,7 @@ def invert(node: Compare) -> Compare:
     return inverse_node
 
 
-def merge_exitcases(exit1, exit2):
+def merge_exitcases(exit1: Optional[Compare], exit2: None) -> Optional[Compare]:
     """
     Merge the exitcases of two Links.
 
@@ -87,6 +87,9 @@ class CFGBuilder(ast.NodeVisitor):
     a program's AST and iteratively build the corresponding CFG.
     """
 
+    def __init__(self, short: bool = True) -> None:
+        self.isShort = short
+
     # ---------- CFG building methods ---------- #
     def build(
         self, name: str, tree: Module, asynchr: bool = False, entry_id: int = 0
@@ -106,7 +109,7 @@ class CFGBuilder(ast.NodeVisitor):
         Returns:
             The CFG produced from the AST.
         """
-        self.cfg = CFG(name, asynchr=asynchr)
+        self.cfg = CFG(name, asynchr=asynchr, short=self.isShort)
         # Tracking of the current block while building the CFG.
         self.current_id = entry_id
         self.current_block = self.new_block()
@@ -130,7 +133,7 @@ class CFGBuilder(ast.NodeVisitor):
         tree = ast.parse(src, mode="exec")
         return self.build(name, tree)
 
-    def build_from_file(self, name: str, filepath: str):
+    def build_from_file(self, name: str, filepath: str) -> CFG:
         """
         Build a CFG from some Python source file.
 
@@ -218,7 +221,7 @@ class CFGBuilder(ast.NodeVisitor):
         # A new sub-CFG is created for the body of the class definition and
         # added to the class CFGs of the current CFG.
         class_body = ast.Module(body=node.body)
-        class_builder = CFGBuilder()
+        class_builder = CFGBuilder(short=self.isShort)
         self.cfg.classcfgs[node.name] = class_builder.build(
             node.name, class_body, asynchr, self.current_id
         )
@@ -238,7 +241,7 @@ class CFGBuilder(ast.NodeVisitor):
         # A new sub-CFG is created for the body of the function definition and
         # added to the function CFGs of the current CFG.
         func_body = ast.Module(body=node.body)
-        func_builder = CFGBuilder()
+        func_builder = CFGBuilder(short=self.isShort)
         self.cfg.functioncfgs[node.name] = func_builder.build(
             node.name, func_body, asynchr, self.current_id
         )
@@ -320,7 +323,7 @@ class CFGBuilder(ast.NodeVisitor):
         self.add_statement(self.current_block, node)
         self.generic_visit(node)
 
-    def visit_AnnAssign(self, node):
+    def visit_AnnAssign(self, node: AnnAssign) -> None:
         self.add_statement(self.current_block, node)
         self.generic_visit(node)
 
@@ -409,7 +412,7 @@ class CFGBuilder(ast.NodeVisitor):
         # Continue building the CFG in the after-while block.
         self.current_block = afterwhile_block
 
-    def visit_For(self, node):
+    def visit_For(self, node: For) -> None:
         loop_guard = self.new_loopguard()
         self.current_block = loop_guard
         self.add_statement(self.current_block, node)
@@ -431,7 +434,7 @@ class CFGBuilder(ast.NodeVisitor):
         # Continue building the CFG in the after-for block.
         self.current_block = afterfor_block
 
-    def visit_Break(self, node):
+    def visit_Break(self, node: Break) -> None:
         # TODO
         pass
 
@@ -439,10 +442,10 @@ class CFGBuilder(ast.NodeVisitor):
         # TODO
         pass
 
-    def visit_Import(self, node):
+    def visit_Import(self, node: Import) -> None:
         self.add_statement(self.current_block, node)
 
-    def visit_ImportFrom(self, node):
+    def visit_ImportFrom(self, node: ImportFrom) -> None:
         self.add_statement(self.current_block, node)
 
     def visit_FunctionDef(self, node: FunctionDef) -> None:
